@@ -20,7 +20,6 @@ import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.EOFException;
 import java.io.IOException;
@@ -37,18 +36,21 @@ public class NullInputStreamTest {
         public TestNullInputStream(final int size) {
             super(size);
         }
+
         public TestNullInputStream(final int size, final boolean markSupported, final boolean throwEofException) {
             super(size, markSupported, throwEofException);
         }
+
         @Override
         protected int processByte() {
-            return (int)getPosition() - 1;
+            return (int) getPosition() - 1;
         }
+
         @Override
         protected void processBytes(final byte[] bytes, final int offset, final int length) {
-            final int startPos = (int)getPosition() - length;
+            final int startPos = (int) getPosition() - length;
             for (int i = offset; i < length; i++) {
-                bytes[i] = (byte)(startPos + i);
+                bytes[i] = (byte) (startPos + i);
             }
         }
 
@@ -69,25 +71,21 @@ public class NullInputStreamTest {
     @Test
     public void testMarkAndReset() throws Exception {
         int position = 0;
-        final int readlimit = 10;
+        final int readLimit = 10;
         try (InputStream input = new TestNullInputStream(100, true, false)) {
 
             assertTrue(input.markSupported(), "Mark Should be Supported");
 
             // No Mark
-            try {
-                input.reset();
-                fail("Read limit exceeded, expected IOException ");
-            } catch (final IOException e) {
-                assertEquals("No position has been marked", e.getMessage(), "No Mark IOException message");
-            }
+            final IOException noMarkException = assertThrows(IOException.class, input::reset);
+            assertEquals("No position has been marked", noMarkException.getMessage(), "No Mark IOException message");
 
             for (; position < 3; position++) {
                 assertEquals(position, input.read(), "Read Before Mark [" + position + "]");
             }
 
             // Mark
-            input.mark(readlimit);
+            input.mark(readLimit);
 
             // Read further
             for (int i = 0; i < 3; i++) {
@@ -98,18 +96,14 @@ public class NullInputStreamTest {
             input.reset();
 
             // Read From marked position
-            for (int i = 0; i < readlimit + 1; i++) {
+            for (int i = 0; i < readLimit + 1; i++) {
                 assertEquals(position + i, input.read(), "Read After Reset [" + i + "]");
             }
 
             // Reset after read limit passed
-            try {
-                input.reset();
-                fail("Read limit exceeded, expected IOException ");
-            } catch (final IOException e) {
-                assertEquals("Marked position [" + position + "] is no longer valid - passed the read limit [" + readlimit + "]", e.getMessage(),
+            final IOException resetException = assertThrows(IOException.class, input::reset, "Read limit exceeded, expected IOException");
+            assertEquals("Marked position [" + position + "] is no longer valid - passed the read limit [" + readLimit + "]", resetException.getMessage(),
                     "Read limit IOException message");
-            }
         }
     }
 
@@ -118,19 +112,11 @@ public class NullInputStreamTest {
         final InputStream input = new TestNullInputStream(100, false, true);
         assertFalse(input.markSupported(), "Mark Should NOT be Supported");
 
-        try {
-            input.mark(5);
-            fail("mark() should throw UnsupportedOperationException");
-        } catch (final UnsupportedOperationException e) {
-            assertEquals(MARK_RESET_NOT_SUPPORTED, e.getMessage(), "mark() error message");
-        }
+        final UnsupportedOperationException markException = assertThrows(UnsupportedOperationException.class, () -> input.mark(5));
+        assertEquals(MARK_RESET_NOT_SUPPORTED, markException.getMessage(), "mark() error message");
 
-        try {
-            input.reset();
-            fail("reset() should throw UnsupportedOperationException");
-        } catch (final UnsupportedOperationException e) {
-            assertEquals(MARK_RESET_NOT_SUPPORTED, e.getMessage(), "reset() error message");
-        }
+        final UnsupportedOperationException resetException = assertThrows(UnsupportedOperationException.class, input::reset);
+        assertEquals(MARK_RESET_NOT_SUPPORTED, resetException.getMessage(), "reset() error message");
         input.close();
     }
 
@@ -149,12 +135,8 @@ public class NullInputStreamTest {
         assertEquals(0, input.available(), "Available after End of File");
 
         // Test reading after the end of file
-        try {
-            final int result = input.read();
-            fail("Should have thrown an IOException, byte=[" + result + "]");
-        } catch (final IOException e) {
-            assertEquals("Read after end of file", e.getMessage());
-        }
+        final IOException e = assertThrows(IOException.class, input::read);
+        assertEquals("Read after end of file", e.getMessage());
 
         // Close - should reset
         input.close();
@@ -185,12 +167,8 @@ public class NullInputStreamTest {
         assertEquals(-1, count3, "Read 3 (EOF)");
 
         // Test reading after the end of file
-        try {
-            final int count4 = input.read(bytes);
-            fail("Should have thrown an IOException, byte=[" + count4 + "]");
-        } catch (final IOException e) {
-            assertEquals("Read after end of file", e.getMessage());
-        }
+        final IOException e = assertThrows(IOException.class, () -> input.read(bytes));
+        assertEquals("Read after end of file", e.getMessage());
 
         // reset by closing
         input.close();
@@ -207,19 +185,16 @@ public class NullInputStreamTest {
 
     @Test
     public void testSkip() throws Exception {
-        final InputStream input = new TestNullInputStream(10, true, false);
-        assertEquals(0, input.read(), "Read 1");
-        assertEquals(1, input.read(), "Read 2");
-        assertEquals(5, input.skip(5), "Skip 1");
-        assertEquals(7, input.read(), "Read 3");
-        assertEquals(2, input.skip(5), "Skip 2"); // only 2 left to skip
-        assertEquals(-1, input.skip(5), "Skip 3 (EOF)"); // End of file
-        try {
-            input.skip(5); //
-            fail("Expected IOException for skipping after end of file");
-        } catch (final IOException e) {
+        try (InputStream input = new TestNullInputStream(10, true, false)) {
+            assertEquals(0, input.read(), "Read 1");
+            assertEquals(1, input.read(), "Read 2");
+            assertEquals(5, input.skip(5), "Skip 1");
+            assertEquals(7, input.read(), "Read 3");
+            assertEquals(2, input.skip(5), "Skip 2"); // only 2 left to skip
+            assertEquals(-1, input.skip(5), "Skip 3 (EOF)"); // End of file
+
+            final IOException e = assertThrows(IOException.class, () -> input.skip(5), "Expected IOException for skipping after end of file");
             assertEquals("Skip after end of file", e.getMessage(), "Skip after EOF IOException message");
         }
-        input.close();
     }
 }
