@@ -24,13 +24,18 @@ import java.io.StringWriter;
 import java.nio.charset.Charset;
 import java.nio.charset.CharsetDecoder;
 import java.nio.charset.StandardCharsets;
+import java.nio.file.StandardOpenOption;
 import java.util.Random;
 
 import org.apache.commons.io.Charsets;
 import org.apache.commons.io.charset.CharsetDecoders;
 import org.junit.jupiter.api.Test;
 
+/**
+ * Tests {@link WriterOutputStream}.
+ */
 public class WriterOutputStreamTest {
+
     private static final String UTF_16LE = StandardCharsets.UTF_16LE.name();
     private static final String UTF_16BE = StandardCharsets.UTF_16BE.name();
     private static final String UTF_16 = StandardCharsets.UTF_16.name();
@@ -219,6 +224,7 @@ public class WriterOutputStreamTest {
                 .setCharset("us-ascii")
                 .setBufferSize(1024)
                 .setWriteImmediately(true)
+                .setOpenOptions(StandardOpenOption.CREATE, StandardOpenOption.READ, StandardOpenOption.WRITE)
                 .get()) {
             // @formatter:on
             out.write("abc".getBytes(StandardCharsets.US_ASCII));
